changeset 2179:2b2cae486387 libavformat

simplify strstart()
author mru
date Fri, 22 Jun 2007 22:35:55 +0000
parents 6e503a584e8f
children 6eb481ce83d9
files cutils.c
diffstat 1 files changed, 6 insertions(+), 14 deletions(-) [+]
line wrap: on
line diff
--- a/cutils.c	Thu Jun 21 09:53:01 2007 +0000
+++ b/cutils.c	Fri Jun 22 22:35:55 2007 +0000
@@ -26,24 +26,16 @@
  * set to the next character in 'str' after the prefix.
  *
  * @param str input string
  * @param val prefix to test
  * @param ptr updated after the prefix in str in there is a match
  * @return TRUE if there is a match
  */
-int strstart(const char *str, const char *val, const char **ptr)
+int strstart(const char *str, const char *pfx, const char **ptr)
 {
-    const char *p, *q;
-    p = str;
-    q = val;
-    while (*q != '\0') {
-        if (*p != *q)
-            return 0;
-        p++;
-        q++;
-    }
-    if (ptr)
-        *ptr = p;
-    return 1;
+    while (*pfx && *pfx++ == *str++);
+    if (!*pfx && ptr)
+        *ptr = str;
+    return !*pfx;
 }
 
 /**
@@ -26,24 +26,16 @@
  *
  * @param str input string
- * @param val prefix to test
+ * @param pfx prefix to test
  * @param ptr updated after the prefix in str in there is a match
  * @return TRUE if there is a match